Module: Fastlane::AppDropper
- Defined in:
- lib/fastlane/plugin/app_dropper.rb,
lib/fastlane/plugin/app_dropper/version.rb
Constant Summary collapse
- VERSION =
"1.0.0"
Class Method Summary collapse
-
.all_classes ⇒ Object
Returns all .rb files inside the "actions" and "helper" directory, which is how fastlane discovers what a plugin provides.
Class Method Details
.all_classes ⇒ Object
Returns all .rb files inside the "actions" and "helper" directory, which is how fastlane discovers what a plugin provides.
7 8 9 |
# File 'lib/fastlane/plugin/app_dropper.rb', line 7 def self.all_classes Dir[File.('**/{actions,helper}/*.rb', File.dirname(__FILE__))] end |